#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://games.moria.org.uk/kye/pygtk
# source           : http://games.moria.org.uk/kye/download/kye-0.9.3.tar.gz

# Package name
NAME="kye"
# Package version
VERSION="0.9.3"
# Source code URL
SOURCE="http://games.moria.org.uk/kye/download/kye-0.9.3.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="COPYING NEWS PKG-INFO README"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="noarch"
BUILD="60.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: kye is a clone of the classic puzzle game Kye to Linux
$NAME:
$NAME: Kye is an unusual little puzzle game, with a variety of different
$NAME: types of objects. It takes a little time to figure out all the
$NAME: objects and their normal behaviour; so 6 starter levels are included
$NAME: to introduce the different objects and different types of level you
$NAME: see them in. Once you have a feel for the game, there are plenty of
$NAME: extra levels to choose from.
$NAME:
$NAME:
$NAME:
END

# Create the desktop entries
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Kye
Exec=Kye %f
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=kye
EOF
cat > $PKG/usr/share/applications/$NAME-edit.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Kye-edit
Exec=Kye-edit %f
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=kye-edit
EOF

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if the icons are present. If they's not, download them
if [ -f kye.svg ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon"
	wget -c http://users.zenwalk.org/user-accounts/gapan/kye/kye.svg
fi
if [ -f kye-edit.svg ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon"
	wget -c http://users.zenwalk.org/user-accounts/gapan/kye/kye-edit.svg
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

# Install on temporary directory
cd $NAME-$VERSION
./setup.py install --root=$PKG
mkdir -p $PKG/usr/share/icons/hicolor/scalable/apps
cp -a $CWD/kye.svg $CWD/kye-edit.svg $PKG/usr/share/icons/hicolor/scalable/apps
mkdir -p $PKG/usr/share/icons/hicolor/32x32/apps
cp -a $CWD/$NAME-$VERSION/kye-icon.png $PKG/usr/share/icons/hicolor/32x32/apps/kye.png
cp -a $CWD/$NAME-$VERSION/kye-edit-icon.png $PKG/usr/share/icons/hicolor/32x32/apps/kye-edit.png

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
/sbin/makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
